	SUBROUTINE SERMAP (N,INUM,ILOC)
C SET THE WORD AND BIT IN THE CORRECT MAP.  THIS ROUTINE IS USED TO
C HANDLE THE RSPACES ENTERED BY THE OPERATOR.  THE ARRAYS
C IRLOC AND IRSPAC ARE USED TO SAVE THE VALUES.
C
C	N		SECOND SUBSCRIPT LOCATION WHERE BIT IS TO BE SET
C	INUM		BIT NUMBER TO BE SET
C	ILOC		FIRST SUBSCRIPT LOCATION WHERE BIT IS TO BE SET
C
C	CALLED BY:	SESPAC
C	CALLS:		NONE
C
	INCLUDE 'SEARCH.INC'
C IF NUMBER IS OUT OF RANGE, SET ENTRY TO ZERO
	IF ((INUM .LT. 1) .OR. (INUM .GT. IRBMAX)) THEN
	  IRLOC(ILOC,N) = 0
C SET THE APPROPRIATE BIT IN IRSPAC AND IRLOC
	ELSE
	  IRLOC(ILOC,N) = (INUM-1)/16 + 1
	  IBIT = MOD(INUM-1,16) + 1
	  IRSPAC(ILOC,N) = IBITS(IBIT)
	END IF
	RETURN
	END
